@@ -1,4 +1,4 @@
 from np_session.components.info import *
 from np_session.components.paths import *
-# from np_session.components.platform_json import *
+from np_session.components.platform_json import *
 from np_session.components.settings_xml import *
