@@ -2,15 +2,20 @@ from __future__ import annotations
 
 import abc
 import enum
-from typing import Any
+import functools
+from typing import Any, MutableMapping
 
+
+import np_logging
 from backports.cached_property import cached_property
+from typing_extensions import Literal
 
 from np_session.databases import State
 from np_session.databases.lims2 import (LIMS2MouseInfo, LIMS2ProjectInfo,
                                         LIMS2UserInfo)
 from np_session.databases.mtrain import MTrain
 
+logger = np_logging.getLogger(__name__)
 
 class InfoBaseClass(abc.ABC):
     "Store details for an object from various databases. The commonly-used format of its name, e.g. '366122' for a mouse ID, can be obtained by converting to str()."
@@ -58,10 +63,14 @@ class Mouse(InfoBaseClass):
     def project(self) -> str | None:
         "Project associated with the mouse."
         return self.lims.project_name if self.lims else None
-
-    @cached_property
-    def state(self) -> State:
-        return State(self.id)
+    
+    @property
+    def state(self) -> MutableMapping[str, Any]:
+        try:
+            return State(self.id)
+        except Exception as exc:
+            logger.error("Failed to load `%r.state`: %r", self, exc)
+        return {}
     
 class User(InfoBaseClass):
     def __init__(self, lims_user_id: str):
@@ -77,9 +86,13 @@ class User(InfoBaseClass):
                 self._lims = {}
         return self._lims
     
-    @cached_property
-    def state(self) -> State:
-        return State(self.id)
+    @property
+    def state(self) -> MutableMapping[str, Any]:
+        try:
+            return State(self.id)
+        except Exception as exc:
+            logger.error("Failed to load `%r.state`: %r", self, exc)
+        return {}
 
 
 class Projects(enum.Enum):
@@ -99,6 +112,18 @@ class Projects(enum.Enum):
     VB = ("NeuropixelVisualBehavior",)
     TTN = ('TaskTrainedNetworksNeuropixel',)
 
+    def latest_session(self, session_type: Literal['ephys', 'hab', 'behavior'] = 'ephys') -> int | None:
+        "Lims session id for latest session for all child projects."
+        for _ in self.value:
+            session_id = Project(_).state.get(f'latest_{session_type}')
+            if session_id:
+                return session_id
+        return None
+    
+    latest_ephys = functools.partialmethod(latest_session, 'ephys')
+    latest_hab = functools.partialmethod(latest_session, 'hab')
+    latest_behavior = functools.partialmethod(latest_session, 'behavior')
+    
 class Project(InfoBaseClass):
     
     def __init__(self, lims_project_name: str):
@@ -114,6 +139,11 @@ class Project(InfoBaseClass):
             return self.id in other.value
         return super().__eq__(other)
     
-    @cached_property
-    def state(self) -> State:
-        return State(self.id)
+    @property
+    def state(self) -> MutableMapping[str, Any]:
+        try:
+            return State(self.id)
+        except Exception as exc:
+            logger.error("Failed to load `%r.state`: %r", self, exc)
+        return {}
+
