@@ -235,8 +235,11 @@ class PlatformJson(pydantic.BaseModel):
     files: Dict[str, Dict[str, Dict[str, List]]] = pydantic.Field(default_factory=dict)
 
     def update(self, field, new) -> None:
+        
         self.load_from_existing()
+        
         existing = getattr(self, field)
+        
         if (not new and new is not False) or existing == new:
             return
         
@@ -245,10 +248,13 @@ class PlatformJson(pydantic.BaseModel):
             new = np_config.merge(copy.deepcopy(getattr(self, field)), new)
             
         logger.debug('Updating %s %s: %s -> %s', self.path.name, field, existing, new)
-        setattr(self, field, new)
-    
+        with self.sync_disabled():
+            setattr(self, field, new)
+        self.write()
+   
 def update_from_session(pj: PlatformJson, session) -> None:
     "Updates fields in a platform json file."
+    #! careful not to execute Session methods that call this platform json instance in a loop
     
     with pj.sync_disabled():
         logger.debug("Updating %s with session %s fields, with write disabled", pj.path.name, session.id)
@@ -264,3 +270,5 @@ def update_from_session(pj: PlatformJson, session) -> None:
         pj.update('hab', session.is_hab)
         
     pj.write()
+
+
