@@ -327,7 +327,9 @@ class Session:
     def foraging_id(self) -> str | None:
         "From lims, mtrain, or platform json, in that order."
         if not hasattr(self, "_foraging_id"):
-            self._foraging_id = self.foraging_id_lims or self.foraging_id_mtrain or self.platform_json.foraging_id
+            self._foraging_id = self.foraging_id_lims or self.foraging_id_mtrain or (
+                self.platform_json.foraging_id if self.platform_json.file_sync else None
+                )
         return self._foraging_id
     
     @foraging_id.setter
@@ -445,11 +447,13 @@ class Session:
     def platform_json(self) -> PlatformJson:
         """Platform D1 json on npexp.
         
-        Not cached so we always get the current contents on disk.
         """
-        platform_json = PlatformJson(self.npexp_path)
-        update_from_session(platform_json, self)
-        return platform_json
+        with contextlib.suppress(AttributeError):
+            self._platform_json.load_from_existing()
+            return self._platform_json
+        self._platform_json = PlatformJson(self.npexp_path)
+        update_from_session(self._platform_json, self)
+        return self._platform_json
     
     def fix_platform_json(self, path_or_obj: Optional[pathlib.Path | PlatformJson] = None):
         if not path_or_obj:
@@ -467,12 +471,13 @@ class Session:
         In the event that the platform.json file does not contain a time, we use the start
         of the day of the session.       
         """
-        fields_to_try = ('ExperimentStartTime', 'ProbeInsertionStartTime', 'CartridgeLowerTime', 'HeadFrameEntryTime', 'workflow_start_time',)
-        for _ in fields_to_try:
-            time = getattr(self.platform_json, _)
-            if isinstance(time, datetime.datetime):
-                return time
-        logger.warning('Could not find experiment start time in %s: using start of day instead', self.platform_json)
+        if self.platform_json.file_sync:
+            fields_to_try = ('ExperimentStartTime', 'ProbeInsertionStartTime', 'CartridgeLowerTime', 'HeadFrameEntryTime', 'workflow_start_time',)
+            for _ in fields_to_try:
+                time = getattr(self.platform_json, _)
+                if isinstance(time, datetime.datetime):
+                    return time
+            logger.warning('Could not find experiment start time in %s: using start of day instead', self.platform_json)
         return datetime.datetime(*self.date.timetuple()[:5])
     
     @cached_property
@@ -483,12 +488,13 @@ class Session:
         In the event that the platform.json file does not contain a time, we use the end
         of the day of the session.       
         """
-        fields_to_try = ('workflow_complete_time', 'ExperimentCompleteTime', 'HeadFrameExitTime',)
-        for _ in fields_to_try:
-            time = getattr(self.platform_json, _)
-            if isinstance(time, datetime.datetime):
-                return time
-        logger.warning('Could not find experiment end time in %s: using end of day instead', self.platform_json)
+        if self.platform_json.file_sync:
+            fields_to_try = ('workflow_complete_time', 'ExperimentCompleteTime', 'HeadFrameExitTime',)
+            for _ in fields_to_try:
+                time = getattr(self.platform_json, _)
+                if isinstance(time, datetime.datetime):
+                    return time
+            logger.warning('Could not find experiment end time in %s: using end of day instead', self.platform_json)
         return datetime.datetime(*self.date.timetuple()[:5]) + datetime.timedelta(days=1) - datetime.timedelta(seconds=1)
     
     @property
@@ -635,10 +641,8 @@ def latest_session(
         return None
     
     return Session(session)
-    
+
 if __name__ == "__main__":
-    logger = np_logging.getLogger()
-    latest_session('TTN')
     if is_connected("lims2"):
         doctest.testmod(verbose=True)
         # optionflags=(doctest.ELLIPSIS, doctest.NORMALIZE_WHITESPACE,
